
======================
LDAP Client Quickstart
======================

.. literalinclude:: /examples/quickstart_client.py
   :language: python

.. _quickstart-server-label:

=======================
LDAP Server Quick Start
=======================

.. literalinclude:: /examples/quickstart_server.py
   :language: python
